==> tecfy_corev2_package-1.1.30.tar.gz: lib/services/web_socket.service.dart <==
part of tecfy_corev2_client_package;

class WebSocketService {
  static bool connected = false;
  static WebSocketChannel? channel;
  static Stream<dynamic>? stream;

  static init() {
    // if (ConnectionService.activeConnection == null ||
    //     ConfigService.token.isEmpty ||
    //     TecfyBasicApp.isTest) return;
    // try {
    //   print(
    //       '========= WebSocket ====  try tp connect to ${ConnectionService.activeConnection!.wsURL}');
    //   channel = WebSocketChannel.connect(
    //       Uri.parse(ConnectionService.activeConnection!.wsURL));

    //   // headers: {'Authorization': 'Bearer ${ConfigService.token}'},
    //   // pingInterval: Duration(seconds: 10));

    //   _initConnection();

    //   stream = channel!.stream.asBroadcastStream();

    //   stream!.listen((data) {
    //     print(
    //         '========= WebSocket ==== new Package revieved -----------------');
    //     print(data);
    //     try {
    //       var package = Package.fromMap(json.decode(data));
    //       _packageReceived(package);
    //     } catch (err) {
    //       print('XXXXXXX stream package parse error $err : [$data]');
    //     }
    //   }, onError: (err) {
    //     print('XXXXXXXXXXXXXXXXXXXXXXXXXXXXX WebSocket Error $err');
    //     connected = false;
    //   }, onDone: () {
    //     print(
    //         'XXXXXXXXXXXXXXXXXXXXXXXXXXXXX WebSocket Done !!!!!!!!!!!!!!!!!!');
    //     connected = false;
    //   });

    //   print('========= WebSocket ==== init');
    // } catch (err) {
    //   print(
    //       'xxxxxxxxxxxxxxx Package socket Error xxxxxxxxxxxxxxxxx ${ConfigService.wsURL}');
    //   print(err);
    // }
  }

  static _initConnection() async {
    try {
      while (channel?.protocol == null) {
        await Future.delayed(Duration(milliseconds: 50));
      }
      if (kDebugMode) print('start send token via web socket');
      channel!.sink.add(ConfigService.token);
      await Future.delayed(Duration(seconds: 2));
      NotificationAppService.loadOldNotifications();
      if (kDebugMode) print('========= WebSocket ==== Connected');
      connected = true;
    } catch (err) {
      print('XXXXXXX initConnection error websocket $err');
    }
  }

  static _packageReceived(Package package) async {
    switch (package.type) {
      case PackageType.newNotification:
        NotificationAppService.onNotificationReceived(package.data);
        break;
      case PackageType.newMultiNotification:
        package.data
            .forEach((n) => NotificationAppService.onNotificationReceived(n));
        NotificationAppService.softNotifications();
        break;
      case PackageType.newMessage:
        MessageService.onMessageReceived(package.data);
        break;
      default:
    }
  }

  static Future<bool> sendPackage(Package package) async {
    try {
      if (WebSocketService.channel == null) {
        return false;
      }
      dynamic data;
      switch (package.type) {
        case PackageType.requestLatestNotification:
          data = package.data;
          break;
        case PackageType.newMessage:
          data = package.data.toMap();
          break;
        case PackageType.messageACK:
          if (kDebugMode)
            print('++++++++++++++++ send messageACK +++++++ ${package.data}');
          data = package.data;
          break;
        default:
          data = package.data;
      }

      if (WebSocketService.channel?.closeCode != null) {
        if (kDebugMode)
          print(
              'XXXXXXXXXXXXXXXXXXXXXXXXXXXXX WebSocket Connection Closed with ${WebSocketService.channel?.closeCode} : Reason ${WebSocketService.channel?.closeReason}');
      }

      WebSocketService.channel?.sink
          .add(json.encode({'type': package.type, 'data': data}));
      return true;
    } catch (err) {
      print(
          'XXXXXXXXXXXXXXXXXXXXXXXXXXXXX Cannot send to WebSocket Connection $err');
    }
    return false;
  }
}

==> tecfy_corev2_package-1.1.78.tar.gz: lib/services/web_socket.service.dart <==
part of tecfy_corev2_client_package;

class WebSocketService {
  static bool connected = false;
  static WebSocketChannel? channel;
  static Stream<dynamic>? stream;

  static init() {
    // if (ConnectionService.activeConnection == null ||
    //     ConfigService.token.isEmpty ||
    //     TecfyBasicApp.isTest) return;
    // try {
    //   print(
    //       '========= WebSocket ====  try tp connect to ${ConnectionService.activeConnection!.wsURL}');
    //   channel = WebSocketChannel.connect(
    //       Uri.parse(ConnectionService.activeConnection!.wsURL));

    //   // headers: {'Authorization': 'Bearer ${ConfigService.token}'},
    //   // pingInterval: Duration(seconds: 10));

    //   _initConnection();

    //   stream = channel!.stream.asBroadcastStream();

    //   stream!.listen((data) {
    //     print(
    //         '========= WebSocket ==== new Package revieved -----------------');
    //     print(data);
    //     try {
    //       var package = Package.fromMap(json.decode(data));
    //       _packageReceived(package);
    //     } catch (err) {
    //       print('XXXXXXX stream package parse error $err : [$data]');
    //     }
    //   }, onError: (err) {
    //     print('XXXXXXXXXXXXXXXXXXXXXXXXXXXXX WebSocket Error $err');
    //     connected = false;
    //   }, onDone: () {
    //     print(
    //         'XXXXXXXXXXXXXXXXXXXXXXXXXXXXX WebSocket Done !!!!!!!!!!!!!!!!!!');
    //     connected = false;
    //   });

    //   print('========= WebSocket ==== init');
    // } catch (err) {
    //   print(
    //       'xxxxxxxxxxxxxxx Package socket Error xxxxxxxxxxxxxxxxx ${ConfigService.wsURL}');
    //   print(err);
    // }
  }

  // static _initConnection() async {
  //   try {
  //     while (channel?.protocol == null) {
  //       await Future.delayed(Duration(milliseconds: 50));
  //     }
  //     if (kDebugMode) print('start send token via web socket');
  //     channel!.sink.add(ConfigService.token);
  //     await Future.delayed(Duration(seconds: 2));
  //     NotificationAppService.loadOldNotifications();
  //     if (kDebugMode) print('========= WebSocket ==== Connected');
  //     connected = true;
  //   } catch (err) {
  //     print('XXXXXXX initConnection error websocket $err');
  //   }
  // }

  // static _packageReceived(Package package) async {
  //   switch (package.type) {
  //     case PackageType.newNotification:
  //       NotificationAppService.onNotificationReceived(package.data);
  //       break;
  //     case PackageType.newMultiNotification:
  //       package.data
  //           .forEach((n) => NotificationAppService.onNotificationReceived(n));
  //       NotificationAppService.softNotifications();
  //       break;
  //     case PackageType.newMessage:
  //       MessageService.onMessageReceived(package.data);
  //       break;
  //     default:
  //   }
  // }

  static Future<bool> sendPackage(Package package) async {
    try {
      if (WebSocketService.channel == null) {
        return false;
      }
      dynamic data;
      switch (package.type) {
        case PackageType.requestLatestNotification:
          data = package.data;
          break;
        case PackageType.newMessage:
          data = package.data.toMap();
          break;
        case PackageType.messageACK:
          if (kDebugMode)
            print('++++++++++++++++ send messageACK +++++++ ${package.data}');
          data = package.data;
          break;
        default:
          data = package.data;
      }

      if (WebSocketService.channel?.closeCode != null) {
        if (kDebugMode)
          print(
              'XXXXXXXXXXXXXXXXXXXXXXXXXXXXX WebSocket Connection Closed with ${WebSocketService.channel?.closeCode} : Reason ${WebSocketService.channel?.closeReason}');
      }

      WebSocketService.channel?.sink
          .add(json.encode({'type': package.type, 'data': data}));
      return true;
    } catch (err) {
      print(
          'XXXXXXXXXXXXXXXXXXXXXXXXXXXXX Cannot send to WebSocket Connection $err');
    }
    return false;
  }
}
